@@ -13,7 +13,7 @@ our @EXPORT_OK = (
 );
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
-our $VERSION = "v0.23.1";
+our $VERSION = "v0.24.0";
 
 1;
 __END__
@@ -116,7 +116,7 @@ The code samples in this section assume C<$observer> has been set to:
 
 Creation operators create and return an I<observable>. They are usually unicast, which means that when an
 L</rx_interval> I<observable> is subscribed to three seperate times there will be three different & distinct recurring
-intervals. Exceptions to this are with L<subjects|/rx_subject>, and that any observable can be transformed into a
+intervals. Exceptions to this are with L<subjects|/rx_subject> and that any observable can be transformed into a
 L<multicasting|https://www.learnrxjs.io/learn-rxjs/operators/multicasting> one using the L</op_share> pipeable
 operator (or by other similar operators).
 
@@ -180,7 +180,7 @@ L<https://rxjs.dev/api/index/const/EMPTY>
 
 L<https://rxjs.dev/api/index/function/from>
 
-Currently, only arrayrefs, promises, observables, and strings are allowed as argument to this function.
+Currently, only arrayrefs, promises, observables and strings are allowed as argument to this function.
 
     # 10, 20, 30, complete
     rx_from([10, 20, 30])->subscribe($observer);
@@ -340,7 +340,7 @@ L<https://rxjs.dev/api/operators/delay>
 
 Works like rxjs's "delay", except the parameter is in seconds instead of ms.
 
-    # (pause 10 seconds) 0, 1, 2, 3
+    # (pause 11 seconds) 0, 1, 2, 3, ...
     rx_interval(1)->pipe( op_delay(10) )->subscribe($observer);
 
 =item op_distinct_until_changed
@@ -412,10 +412,15 @@ L<https://rxjs.dev/api/operators/filter>
 L<https://rxjs.dev/api/operators/first>
 
     # (pause 7 seconds) 6, complete
-    rx_interval(
+    rx_interval(1)->pipe(
         op_first(sub { $_[0] > 5 }),
     )->subscribe($observer);
 
+    # 0, complete
+    rx_interval(0.7)->pipe(
+        op_first(),
+    )->subscribe($observer);
+
 =item op_map
 
 L<https://rxjs.dev/api/operators/map>
@@ -438,7 +443,7 @@ L<https://rxjs.dev/api/operators/mapTo>
 
 L<https://rxjs.dev/api/operators/mergeMap>
 
-    # 11, 21, 31, 12, 22, 32, 13, 23, 33
+    # 11, 21, 31, 12, 22, 32, 13, 23, 33, complete
     rx_of(10, 20, 30)->pipe(
         op_merge_map(sub ($x) {
             return rx_interval(1)->pipe(
@@ -467,7 +472,7 @@ L<https://rxjs.dev/api/operators/pairwise>
 
 L<https://rxjs.dev/api/operators/pluck>
 
-    # Mary, Paul, undef, undef, undef
+    # Mary, Paul, undef, undef, undef, complete
     rx_of(
         {name => {first => 'Mary'}},
         {name => {first => 'Paul'}},
@@ -572,6 +577,15 @@ L<https://rxjs.dev/api/operators/tap>
         op_tap(sub {say "foo$_[0]"}),
     )->subscribe($observer);
 
+=item op_with_latest_from
+
+L<https://rxjs.dev/api/operators/withLatestFrom>
+
+    # [0, 0], [1, 1], [2, 3], [3, 4], [4, 6], ...
+    rx_interval(1)->pipe(
+        op_with_latest_from(rx_interval(1)),
+    )->subscribe($observer);
+
 =back
 
 =head1 OBSERVABLE METHODS
@@ -602,7 +616,7 @@ L<http://reactivex.io/rxjs/class/es6/Observable.js~Observable.html#instance-meth
 
 L<http://reactivex.io/rxjs/class/es6/Observable.js~Observable.html#instance-method-pipe>
 
-    # 2, 6
+    # 2, 6, complete
     rx_interval(1)->pipe(
         op_take(5),
         op_filter(sub {$_[0] % 2 == 1}),
