@@ -26,13 +26,17 @@ sub rx_combine_latest {
     return rx_observable->new(sub {
         my ($subscriber) = @_;
 
+        my $sources = [@$sources];
+
         my %own_subscriptions;
         my $i = 0;
         my %didnt_emit = map {($i++, 1)} @$sources;
         my @latest_values;
         my $num_active = @$sources;
 
-        get_subscription_from_subscriber($subscriber)->add_dependents(\%own_subscriptions);
+        get_subscription_from_subscriber($subscriber)->add_dependents(
+            \%own_subscriptions, sub { undef @$sources },
+        );
 
         for (my $i = 0; $i < @$sources; $i++) {
             my $j = $i;
@@ -62,7 +66,7 @@ sub rx_combine_latest {
             $source->subscribe($own_observer);
         }
 
-        return \%own_subscriptions;
+        return;
     });
 }
 
