@@ -14,7 +14,7 @@ use Exporter 'import';
 our @EXPORT_OK = qw/
     op_concat_map op_debounce_time op_delay op_distinct_until_changed op_distinct_until_key_changed op_end_with
     op_exhaust_map op_filter op_first op_map op_map_to op_merge_map op_multicast op_pairwise op_pluck op_ref_count
-    op_scan op_share op_start_with op_switch_map op_take op_take_until op_take_while op_tap
+    op_scan op_share op_start_with op_switch_map op_take op_take_until op_take_while op_tap op_with_latest_from
 /;
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
@@ -815,6 +815,59 @@ sub op_tap {
     };
 }
 
+sub op_with_latest_from {
+    my (@other_observables) = @_;
+
+    return sub {
+        my ($source) = @_;
+
+        return rx_observable->new(sub {
+            my ($subscriber) = @_;
+
+            my @other_observables = @other_observables;
+            my $i = 0;
+            my %didnt_emit = map {($i++, 1)} @other_observables;
+            my @latest_values;
+            my %other_subscriptions;
+
+            get_subscription_from_subscriber($subscriber)->add_dependents(
+                \%other_subscriptions, sub { undef @other_observables },
+            );
+
+            for (my $i = 0; $i < @other_observables; $i++) {
+                my $j = $i;
+                my $other_observable = $other_observables[$j];
+
+                my $other_subscription = RxPerl::Subscription->new;
+                $other_subscriptions{$other_subscription} = $other_subscription;
+                $other_observable->subscribe({
+                    new_subscription => $other_subscription,
+                    next     => sub {
+                        my ($value) = @_;
+
+                        $latest_values[$j] = $value;
+                        delete $didnt_emit{$j};
+                    },
+                    error    => $subscriber->{error},
+                });
+            }
+
+            $source->subscribe({
+                %$subscriber,
+                next => sub {
+                    my ($value) = @_;
+
+                    if (! %didnt_emit) {
+                        $subscriber->{next}->([$value, @latest_values]) if defined $subscriber->{next};
+                    }
+                },
+            });
+
+            return;
+        });
+    };
+}
+
 sub _eqq {
     my ($x, $y) = @_;
 
